@@ -15,15 +15,16 @@ class ChartPlugin(Plugin):
             return
 
         # Update snippet
-        if "chart" in snippet.header:
-            spec_yaml = str(snippet.input).strip()
-            spec_python = yaml.safe_load(spec_yaml)
-            spec = json.dumps(spec_python, ensure_ascii=False)
-            spec = spec.replace("'", "\\'")
-            template = Template(self.read_asset("markup.html"))
-            self.count += 1
-            chart = {"spec": spec, "elem": f"livemark-chart-{self.count}"}
-            snippet.output = template.render(chart=chart) + "\n"
+        if snippet.modifier == "chart":
+            if snippet.language == "yaml":
+                spec_yaml = str(snippet.input).strip()
+                spec_python = yaml.safe_load(spec_yaml)
+                spec = json.dumps(spec_python, ensure_ascii=False)
+                spec = spec.replace("'", "\\'")
+                template = Template(self.read_asset("markup.html"))
+                self.count += 1
+                chart = {"spec": spec, "elem": f"livemark-chart-{self.count}"}
+                snippet.output = template.render(chart=chart) + "\n"
 
     def process_markup(self, markup):
         markup.add_script("https://unpkg.com/vega@5.20.2/build/vega.min.js")
