@@ -2,11 +2,11 @@ from ...plugin import Plugin
 
 
 class PagesPlugin(Plugin):
-    priority = 90
+    priority = 80
     profile = {
         "type": "object",
         "properties": {
-            "list": {
+            "items": {
                 "type": "array",
                 "items": {
                     "type": "object",
@@ -19,6 +19,9 @@ class PagesPlugin(Plugin):
         },
     }
 
+    def process_config(self, config):
+        self.config.setdefault("items", self.config.pop("self", []))
+
     def process_markup(self, markup):
         if not self.config:
             return
@@ -26,8 +29,8 @@ class PagesPlugin(Plugin):
         # Prepare context
         current = "/"
         if self.document.target != "index.html":
-            current = f"/{markup.document.target}"
-        list = self.config["list"]
+            current = f"/{self.document.target}"
+        items = self.config["items"]
 
         # Update markup
         markup.add_style("style.css")
@@ -35,5 +38,5 @@ class PagesPlugin(Plugin):
             "markup.html",
             target="#livemark-left",
             current=current,
-            list=list,
+            items=items,
         )
